@@ -12,12 +12,15 @@
 #include <jg_jnu.h>
 #include <gtk_java.h>
 
+#include "org_gnu_gnome_DruidPageEdge.h"
+
 #ifdef __cplusplus
+
 extern "C" 
 {
 #endif
 
-gchar * GnomeDruidPageEdge_get_title (GnomeDruidPageEdge * cptr) 
+static gchar * GnomeDruidPageEdge_get_title (GnomeDruidPageEdge * cptr) 
 {
     return cptr->title;
 }
@@ -34,7 +37,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_DruidPageEdge_getTitle (JNIEnv *env
     return (*env)->NewStringUTF(env, result_g);
 }
 
-gchar * GnomeDruidPageEdge_get_text (GnomeDruidPageEdge * cptr) 
+static gchar * GnomeDruidPageEdge_get_text (GnomeDruidPageEdge * cptr) 
 {
     return cptr->text;
 }
@@ -51,7 +54,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_DruidPageEdge_getText (JNIEnv *env,
     return (*env)->NewStringUTF(env, result_g);
 }
 
-GdkPixbuf * GnomeDruidPageEdge_get_logo_image (GnomeDruidPageEdge * cptr) 
+static GdkPixbuf * GnomeDruidPageEdge_get_logo_image (GnomeDruidPageEdge * cptr) 
 {
     return cptr->logo_image;
 }
@@ -69,7 +72,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageEdge_getLogoImage (JNIEnv
     		(GBoxedFreeFunc) gdk_color_free);
 }
 
-GdkPixbuf * GnomeDruidPageEdge_get_watermark_image (GnomeDruidPageEdge * cptr) 
+static GdkPixbuf * GnomeDruidPageEdge_get_watermark_image (GnomeDruidPageEdge * cptr) 
 {
     return cptr->watermark_image;
 }
@@ -87,7 +90,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageEdge_getWatermarkImage (JN
     		(GBoxedFreeFunc) gdk_color_free);
 }
 
-GdkPixbuf * GnomeDruidPageEdge_get_top_watermark_image (GnomeDruidPageEdge * cptr) 
+static GdkPixbuf * GnomeDruidPageEdge_get_top_watermark_image (GnomeDruidPageEdge * cptr) 
 {
     return cptr->top_watermark_image;
 }
@@ -105,7 +108,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageEdge_getTopWatermarkImage
     		(GBoxedFreeFunc) gdk_color_free);
 }
 
-GdkColor * GnomeDruidPageEdge_get_background_color (GnomeDruidPageEdge * cptr) 
+static GdkColor * GnomeDruidPageEdge_get_background_color (GnomeDruidPageEdge * cptr) 
 {
     return (GdkColor *)&cptr->background_color;
 }
@@ -121,7 +124,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageEdge_getBackgroundColor (J
     return getHandleFromPointer(env, GnomeDruidPageEdge_get_background_color (cptr_g));
 }
 
-GdkColor * GnomeDruidPageEdge_get_textbox_color (GnomeDruidPageEdge * cptr) 
+static GdkColor * GnomeDruidPageEdge_get_textbox_color (GnomeDruidPageEdge * cptr) 
 {
     return (GdkColor *)&cptr->textbox_color;
 }
@@ -139,7 +142,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageEdge_getTextboxColor (JNIE
     		(GBoxedFreeFunc) gdk_color_free);
 }
 
-GdkColor * GnomeDruidPageEdge_get_logo_background_color (GnomeDruidPageEdge * cptr) 
+static GdkColor * GnomeDruidPageEdge_get_logo_background_color (GnomeDruidPageEdge * cptr) 
 {
     return (GdkColor *)&cptr->logo_background_color;
 }
@@ -157,7 +160,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageEdge_getLogoBackgroundColo
     		(GBoxedFreeFunc) gdk_color_free);
 }
 
-GdkColor * GnomeDruidPageEdge_get_title_color (GnomeDruidPageEdge * cptr) 
+static GdkColor * GnomeDruidPageEdge_get_title_color (GnomeDruidPageEdge * cptr) 
 {
     return (GdkColor *)&cptr->title_color;
 }
@@ -175,7 +178,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageEdge_getTitleColor (JNIEnv
     		(GBoxedFreeFunc) gdk_color_free);
 }
 
-GdkColor * GnomeDruidPageEdge_get_text_color (GnomeDruidPageEdge * cptr) 
+static GdkColor * GnomeDruidPageEdge_get_text_color (GnomeDruidPageEdge * cptr) 
 {
     return (GdkColor *)&cptr->text_color;
 }
@@ -193,7 +196,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_DruidPageEdge_getTextColor (JNIEnv
     		(GBoxedFreeFunc) gdk_color_free);
 }
 
-GnomeEdgePosition GnomeDruidPageEdge_get_position (GnomeDruidPageEdge * cptr) 
+static GnomeEdgePosition GnomeDruidPageEdge_get_position (GnomeDruidPageEdge * cptr) 
 {
     return cptr->position;
 }
